@@ -36,6 +36,8 @@
 #include "gpm-conf.h"
 #include "gpm-cell-unit.h"
 #include "gpm-cell.h"
+#include "gpm-phone.h"
+#include "gpm-control.h"
 #include "gpm-debug.h"
 #include "gpm-warnings.h"
 #include "gpm-profile.h"
@@ -51,18 +53,20 @@ static void     gpm_cell_array_finalize   (GObject	     *object);
 
 struct GpmCellArrayPrivate
 {
-	HalGManager	*hal_manager;
-	GpmCellUnit	 unit;
-	GpmAcAdapter	*ac_adapter;
-	GpmProfile	*profile;
-	GpmConf		*conf;
-	GpmWarnings	*warnings;
-	GpmWarningsState warnings_state;
-	GPtrArray	*array;
-	gboolean	 use_profile_calc;
-	gboolean	 done_fully_charged;
-	gboolean	 done_recall;
-	gboolean	 done_capacity;
+	HalGManager		*hal_manager;
+	GpmCellUnit		 unit;
+	GpmAcAdapter		*ac_adapter;
+	GpmProfile		*profile;
+	GpmConf			*conf;
+	GpmPhone		*phone;
+	GpmControl		*control;
+	GpmWarnings		*warnings;
+	GpmWarningsState	 warnings_state;
+	GPtrArray		*array;
+	gboolean		 use_profile_calc;
+	gboolean		 done_fully_charged;
+	gboolean		 done_recall;
+	gboolean		 done_capacity;
 };
 
 enum {
@@ -342,7 +346,8 @@ gpm_cell_array_update (GpmCellArray *cell_array)
 	/* Perform following calculations with floating point otherwise we might
 	 * get an with batteries which have a very small charge unit and consequently
 	 * a very high charge. Fixes bug #327471 */
-	if (unit->kind != GPM_CELL_UNIT_KIND_PRIMARY) {
+	if (unit->kind == GPM_CELL_UNIT_KIND_PRIMARY &&
+	    unit->charge_current > 0 && unit->charge_last_full > 0) {
 		gint pc = 100 * ((gfloat)unit->charge_current /
 				(gfloat)unit->charge_last_full);
 		if (pc < 0) {
@@ -666,12 +671,14 @@ gpm_cell_array_index_udi (GpmCellArray *cell_array, const gchar *udi)
 {
 	gint i;
 	guint length;
+	const gchar *cell_udi;
 	GpmCell *cell;
 
 	length = cell_array->priv->array->len;
 	for (i=0;i<length;i++) {
 		cell = (GpmCell *) g_ptr_array_index (cell_array->priv->array, i);
-		if (strcmp (gpm_cell_get_udi (cell), udi) == 0) {
+		cell_udi = gpm_cell_get_udi (cell);
+		if (cell_udi != NULL && strcmp (cell_udi, udi) == 0) {
 			gpm_debug ("Found %s with udi check", udi);
 			return i;
 		}
@@ -747,10 +754,10 @@ gpm_cell_array_collection_changed (GpmCellArray *cell_array)
 }
 
 /**
- * gpm_cell_array_add:
+ * gpm_cell_array_add_hal_udi:
  */
 static gboolean
-gpm_cell_array_add (GpmCellArray *cell_array, const gchar *udi)
+gpm_cell_array_add_hal_udi (GpmCellArray *cell_array, const gchar *udi)
 {
 	GpmCell *cell;
 	GpmCellUnit *unit;
@@ -789,7 +796,7 @@ gpm_cell_array_add (GpmCellArray *cell_array, const gchar *udi)
 			  G_CALLBACK (gpm_cell_charging_changed_cb), cell_array);
 	g_signal_connect (cell, "discharging-changed",
 			  G_CALLBACK (gpm_cell_discharging_changed_cb), cell_array);
-	gpm_cell_set_type (cell, unit->kind, udi);
+	gpm_cell_set_hal_udi (cell, udi);
 	gpm_cell_print (cell);
 
 	g_ptr_array_add (cell_array->priv->array, (gpointer) cell);
@@ -810,6 +817,15 @@ gpm_cell_array_coldplug (GpmCellArray *cell_array)
 	GError *error;
 	gchar **device_names = NULL;
 	gboolean ret;
+	GpmCellUnit *unit;
+
+	unit = &(cell_array->priv->unit);
+
+	/* we treat phones as hotpluggable devices only */
+	if (unit->kind == GPM_CELL_UNIT_KIND_PHONE) {
+		gpm_phone_coldplug (cell_array->priv->phone);
+		return TRUE;
+	}
 
 	/* get all the hal devices of this type */
 	error = NULL;
@@ -822,7 +838,7 @@ gpm_cell_array_coldplug (GpmCellArray *cell_array)
 
 	/* Try to add all, the add will fail for batteries not of the correct type */
 	for (i=0; device_names[i]; i++) {
-		gpm_cell_array_add (cell_array, device_names[i]);
+		gpm_cell_array_add_hal_udi (cell_array, device_names[i]);
 	}
 
 	hal_gmanager_free_capability (device_names);
@@ -931,6 +947,14 @@ gpm_cell_array_get_description (GpmCellArray *cell_array)
 		return g_strdup_printf ("%s (%i%%)\n", type_desc, unit->percentage);
 	}
 
+	/* we care if we are on AC */
+	if (unit->kind == GPM_CELL_UNIT_KIND_PHONE) {
+		if (unit->is_charging == TRUE || unit->is_discharging == FALSE) {
+			return g_strdup_printf ("%s charging (%i%%)\n", type_desc, unit->percentage);
+		}
+		return g_strdup_printf ("%s (%i%%)\n", type_desc, unit->percentage);
+	}
+
 	/* don't display the text if we are low in accuracy */
 	accuracy = gpm_profile_get_accuracy (cell_array->priv->profile, unit->percentage);
 	gpm_debug ("accuracy = %i", accuracy);
@@ -1056,7 +1080,7 @@ hal_new_capability_cb (HalGManager  *hal_manager,
 	gpm_debug ("udi=%s, capability=%s", udi, capability);
 
 	if (strcmp (capability, "battery") == 0) {
-		gpm_cell_array_add (cell_array, udi);
+		gpm_cell_array_add_hal_udi (cell_array, udi);
 	}
 }
 
@@ -1089,7 +1113,7 @@ hal_device_added_cb (HalGManager  *hal_manager,
 
 	/* if a battery, then add */
 	if (is_battery == TRUE) {
-		gpm_cell_array_add (cell_array, udi);
+		gpm_cell_array_add_hal_udi (cell_array, udi);
 	}
 	g_object_unref (device);
 }
@@ -1116,6 +1140,70 @@ conf_key_changed_cb (GpmConf      *conf,
 	}
 }
 
+/**
+ * phone_device_added_cb:
+ **/
+static void
+phone_device_added_cb (GpmPhone     *phone,
+		       guint        *index,
+		       GpmCellArray *cell_array)
+{
+
+	GpmCell *cell;
+	GpmCellUnit *unit;
+
+	unit = &(cell_array->priv->unit);
+
+	/* ignore non-phones */
+	if (unit->kind != GPM_CELL_UNIT_KIND_PHONE) {
+		return;
+	}
+
+	cell = gpm_cell_new ();
+	g_signal_connect (cell, "percent-changed",
+			  G_CALLBACK (gpm_cell_percent_changed_cb), cell_array);
+	g_signal_connect (cell, "charging-changed",
+			  G_CALLBACK (gpm_cell_charging_changed_cb), cell_array);
+	g_signal_connect (cell, "discharging-changed",
+			  G_CALLBACK (gpm_cell_discharging_changed_cb), cell_array);
+	gpm_cell_set_phone_index (cell, 0);
+	gpm_cell_print (cell);
+
+	g_ptr_array_add (cell_array->priv->array, (gpointer) cell);
+
+	/* global collection has changed */
+	gpm_cell_array_collection_changed (cell_array);
+}
+
+/**
+ * phone_device_removed_cb:
+ **/
+static void
+phone_device_removed_cb (GpmPhone     *phone,
+		         guint         index,
+		         GpmCellArray *cell_array)
+{
+	GpmCell *cell;
+	GpmCellUnit *unit;
+
+	unit = &(cell_array->priv->unit);
+
+	/* ignore non-phones */
+	if (unit->kind != GPM_CELL_UNIT_KIND_PHONE) {
+		return;
+	}
+
+	/* we unref as the device has gone away (only support one phone) */
+	cell = (GpmCell *) g_ptr_array_index (cell_array->priv->array, 0);
+	g_object_unref (cell);
+
+	/* remove from the devicestore */
+	g_ptr_array_remove_index (cell_array->priv->array, index);
+
+	/* global collection has changed */
+	gpm_cell_array_collection_changed (cell_array);
+}
+
 /**
  * hal_daemon_start_cb:
  **/
@@ -1138,6 +1226,19 @@ hal_daemon_stop_cb (HalGManager  *hal_manager,
 	gpm_cell_array_free (cell_array);
 }
 
+/**
+ * control_sleep_action_cb:
+ **/
+static void
+control_sleep_action_cb (GpmControl      *control,
+			 GpmControlAction action,
+		         GpmCellArray    *cell_array)
+{
+	/* we rescan all cells on resume as the battery may have been
+	 * removed or changed whilst we were asleep */
+	gpm_cell_array_collection_changed (cell_array);
+}
+
 /**
  * gpm_cell_array_class_init:
  * @cell_array: This class instance
@@ -1276,6 +1377,17 @@ gpm_cell_array_init (GpmCellArray *cell_array)
 	g_signal_connect (cell_array->priv->hal_manager, "daemon-stop",
 			  G_CALLBACK (hal_daemon_stop_cb), cell_array);
 
+	cell_array->priv->phone = gpm_phone_new ();
+	g_signal_connect (cell_array->priv->phone, "device-added",
+			  G_CALLBACK (phone_device_added_cb), cell_array);
+	g_signal_connect (cell_array->priv->phone, "device-removed",
+			  G_CALLBACK (phone_device_removed_cb), cell_array);
+
+	/* use the control object  */
+	cell_array->priv->control = gpm_control_new ();
+	g_signal_connect (cell_array->priv->control, "resume",
+			  G_CALLBACK (control_sleep_action_cb), cell_array);
+
 	gpm_cell_unit_init (&cell_array->priv->unit);
 }
 
@@ -1297,11 +1409,13 @@ gpm_cell_array_finalize (GObject *object)
 	gpm_cell_array_free (cell_array);
 	g_ptr_array_free (cell_array->priv->array, TRUE);
 
+	g_object_unref (cell_array->priv->phone);
 	g_object_unref (cell_array->priv->ac_adapter);
 	g_object_unref (cell_array->priv->warnings);
 	g_object_unref (cell_array->priv->hal_manager);
 	g_object_unref (cell_array->priv->profile);
 	g_object_unref (cell_array->priv->conf);
+	g_object_unref (cell_array->priv->control);
 }
 
 /**
@@ -1316,3 +1430,94 @@ gpm_cell_array_new (void)
 	return GPM_CELL_ARRAY (cell_array);
 }
 
+/***************************************************************************
+ ***                          MAKE CHECK TESTS                           ***
+ ***************************************************************************/
+#ifdef GPM_BUILD_TESTS
+#include "gpm-self-test.h"
+
+guint recall_count2 = 0;
+
+static void
+gpm_cell_array_perhaps_recall_cb (GpmCellArray *cell_array, gchar *oem_vendor, gchar *website, gpointer data)
+{
+	recall_count2++;
+}
+
+void
+gpm_st_cell_array (GpmSelfTest *test)
+{
+	GpmCell *cell;
+	GpmCellArray *cell_array;
+//	GpmCellUnit *unit;
+	gchar *desc;
+	gboolean ret;
+	guint count;
+
+	if (gpm_st_start (test, "GpmCellArray", CLASS_AUTO) == FALSE) {
+		return;
+	}
+
+	/************************************************************/
+	gpm_st_title (test, "make sure we get a non null cell array");
+	cell_array = gpm_cell_array_new ();
+	g_signal_connect (cell_array, "perhaps-recall",
+			  G_CALLBACK (gpm_cell_array_perhaps_recall_cb), NULL);
+	if (cell_array != NULL) {
+		gpm_st_success (test, "got GpmCellArray");
+	} else {
+		gpm_st_failed (test, "could not get GpmCellArray");
+	}
+
+	/************************************************************/
+	gpm_st_title (test, "make sure we get set type");
+	ret = gpm_cell_array_set_type (cell_array, GPM_CELL_UNIT_KIND_PRIMARY);
+	if (ret == TRUE) {
+		gpm_st_success (test, "set type");
+	} else {
+		gpm_st_failed (test, "could not set type");
+	}
+
+	/************************************************************/
+	gpm_st_title (test, "make sure we got a single recall notice");
+	if (recall_count2 == 1) {
+		gpm_st_success (test, "got recall");
+	} else {
+		gpm_st_failed (test, "did not get recall (install fdi?)");
+	}
+
+	/************************************************************/
+	gpm_st_title (test, "make sure we got 1 cell");
+	count = gpm_cell_array_get_num_cells (cell_array);
+	if (count == 1) {
+		gpm_st_success (test, "got 1 cell");
+	} else {
+		gpm_st_failed (test, "got %i cells", count);
+	}
+
+	/************************************************************/
+	gpm_st_title (test, "make sure we get a full description for cell array");
+	desc = gpm_cell_array_get_description (cell_array);
+	if (desc != NULL) {
+		gpm_st_success (test, "got description %s", desc);
+		g_free (desc);
+	} else {
+		gpm_st_failed (test, "could not get description");
+	}
+
+	/************************************************************/
+	gpm_st_title (test, "make sure we get a valid cell");
+	cell = gpm_cell_array_get_cell (cell_array, 0);
+	if (cell != NULL) {
+		gpm_st_success (test, "got correct cell");
+	} else {
+		gpm_st_failed (test, "could not get correct cell");
+	}
+
+	g_object_unref (cell_array);
+
+	gpm_st_end (test);
+}
+
+#endif
+
