@@ -32,6 +32,7 @@
 #include "gpm-cell.h"
 #include "gpm-cell-unit.h"
 #include "gpm-debug.h"
+#include "gpm-phone.h"
 
 static void     gpm_cell_class_init (GpmCellClass *klass);
 static void     gpm_cell_init       (GpmCell      *cell);
@@ -43,11 +44,13 @@ struct GpmCellPrivate
 {
 	HalGDevice	*hal_device;
 	GpmCellUnit	 unit;
+	GpmPhone	*phone;
 	gchar		*product;
 	gchar		*vendor;
 	gchar		*technology;
 	gchar		*serial;
 	gchar		*model;
+	gulong		 sig_device_refresh;
 };
 
 enum {
@@ -80,10 +83,10 @@ gpm_cell_get_unit (GpmCell *cell)
 }
 
 /**
- * gpm_cell_set_type:
+ * gpm_cell_refresh_hal_all:
  **/
 static gboolean
-gpm_cell_refresh_all (GpmCell *cell)
+gpm_cell_refresh_hal_all (GpmCell *cell)
 {
 	HalGDevice *device;
 	GpmCellUnit *unit;
@@ -91,7 +94,7 @@ gpm_cell_refresh_all (GpmCell *cell)
 	gboolean is_recalled;
 
 	device = cell->priv->hal_device;
-	unit = &(cell->priv->unit);
+	unit = gpm_cell_get_unit (cell);
 
 	/* batteries might be missing */
 	hal_gdevice_get_bool (device, "battery.present", &unit->is_present, NULL);
@@ -236,9 +239,12 @@ hal_device_property_modified_cb (HalGDevice   *device,
 				 gboolean      finally,
 				 GpmCell      *cell)
 {
-	GpmCellUnit *unit = &(cell->priv->unit);
+	GpmCellUnit *unit;
 	const gchar *udi = hal_gdevice_get_udi (device);
 	guint time_hal;
+
+	unit = gpm_cell_get_unit (cell);
+
 	gpm_debug ("udi=%s, key=%s, added=%i, removed=%i, finally=%i",
 		   udi, key, is_added, is_removed, finally);
 
@@ -251,7 +257,7 @@ hal_device_property_modified_cb (HalGDevice   *device,
 	/* update values in the struct */
 	if (strcmp (key, "battery.present") == 0) {
 		hal_gdevice_get_bool (device, key, &unit->is_present, NULL);
-		gpm_cell_refresh_all (cell);
+		gpm_cell_refresh_hal_all (cell);
 
 	} else if (strcmp (key, "battery.rechargeable.is_charging") == 0) {
 		hal_gdevice_get_bool (device, key, &unit->is_charging, NULL);
@@ -310,7 +316,7 @@ hal_device_property_modified_cb (HalGDevice   *device,
 		    battery_key_changed (device, "battery.serial", cell->priv->serial) ||
 		    battery_key_changed (device, "battery.model", cell->priv->model)) {
 		    	/* we have to refresh all, as it might be a different battery */
-			gpm_cell_refresh_all (cell);
+			gpm_cell_refresh_hal_all (cell);
 		}
 	}
 }
@@ -319,7 +325,23 @@ hal_device_property_modified_cb (HalGDevice   *device,
  * gpm_cell_set_type:
  **/
 gboolean
-gpm_cell_set_type (GpmCell *cell, GpmCellUnitKind type, const gchar *udi)
+gpm_cell_set_type (GpmCell *cell, GpmCellUnitKind kind)
+{
+	GpmCellUnit *unit;
+
+	g_return_val_if_fail (cell != NULL, FALSE);
+	g_return_val_if_fail (GPM_IS_CELL (cell), FALSE);
+
+	unit = gpm_cell_get_unit (cell);
+	unit->kind = kind;
+	return TRUE;
+}
+
+/**
+ * gpm_cell_set_hal_udi:
+ **/
+gboolean
+gpm_cell_set_hal_udi (GpmCell *cell, const gchar *udi)
 {
 	gboolean ret;
 	HalGDevice *device;
@@ -329,7 +351,7 @@ gpm_cell_set_type (GpmCell *cell, GpmCellUnitKind type, const gchar *udi)
 	g_return_val_if_fail (cell != NULL, FALSE);
 	g_return_val_if_fail (GPM_IS_CELL (cell), FALSE);
 
-	unit = &(cell->priv->unit);
+	unit = gpm_cell_get_unit (cell);
 	device = cell->priv->hal_device;
 
 	ret = hal_gdevice_set_udi (device, udi);
@@ -357,11 +379,33 @@ gpm_cell_set_type (GpmCell *cell, GpmCellUnitKind type, const gchar *udi)
 	}
 	g_free (battery_kind_str);
 
-	gpm_cell_refresh_all (cell);
+	gpm_cell_refresh_hal_all (cell);
 
 	return TRUE;
 }
 
+/**
+ * gpm_cell_set_phone_index:
+ **/
+gboolean
+gpm_cell_set_phone_index (GpmCell *cell, guint index)
+{
+	GpmCellUnit *unit;
+
+	g_return_val_if_fail (cell != NULL, FALSE);
+	g_return_val_if_fail (GPM_IS_CELL (cell), FALSE);
+
+	unit = gpm_cell_get_unit (cell);
+	unit->kind = GPM_CELL_UNIT_KIND_PHONE;
+
+	unit->is_discharging = TRUE;
+	unit->is_present = TRUE;
+	unit->percentage = gpm_phone_get_percentage (cell->priv->phone, 0);
+	unit->is_charging = gpm_phone_get_on_ac (cell->priv->phone, 0);
+	unit->is_discharging = !unit->is_charging;
+	return TRUE;
+}
+
 /**
  * gpm_cell_get_udi:
  **/
@@ -385,7 +429,7 @@ gpm_cell_get_icon (GpmCell *cell)
 	g_return_val_if_fail (cell != NULL, NULL);
 	g_return_val_if_fail (GPM_IS_CELL (cell), NULL);
 
-	unit = &(cell->priv->unit);
+	unit = gpm_cell_get_unit (cell);
 	return gpm_cell_unit_get_icon (unit);
 }
 
@@ -420,7 +464,7 @@ gpm_cell_print (GpmCell *cell)
 	g_return_val_if_fail (cell != NULL, FALSE);
 	g_return_val_if_fail (GPM_IS_CELL (cell), FALSE);
 
-	unit = &(cell->priv->unit);
+	unit = gpm_cell_get_unit (cell);
 	gpm_cell_unit_print (unit);
 	return TRUE;
 }
@@ -437,7 +481,7 @@ gpm_cell_get_description (GpmCell *cell)
 	g_return_val_if_fail (cell != NULL, NULL);
 	g_return_val_if_fail (GPM_IS_CELL (cell), NULL);
 
-	unit = &(cell->priv->unit);
+	unit = gpm_cell_get_unit (cell);
 
 	details = g_string_new ("");
 	if (cell->priv->product) {
@@ -556,6 +600,44 @@ gpm_cell_get_description (GpmCell *cell)
 	return g_string_free (details, FALSE);
 }
 
+/**
+ * phone_device_refresh_cb:
+ **/
+static void
+phone_device_refresh_cb (GpmPhone     *phone,
+		         guint         index,
+		         GpmCell      *cell)
+{
+	GpmCellUnit *unit;
+	gboolean is_charging;
+	guint percentage;
+
+	g_return_if_fail (cell != NULL);
+	g_return_if_fail (GPM_IS_CELL (cell));
+
+	unit = gpm_cell_get_unit (cell);
+
+	/* ignore non-phones */
+	if (unit->kind != GPM_CELL_UNIT_KIND_PHONE) {
+		return;
+	}
+
+	percentage = gpm_phone_get_percentage (cell->priv->phone, 0);
+	is_charging = gpm_phone_get_on_ac (cell->priv->phone, 0);
+
+	if (unit->is_charging != is_charging) {
+		unit->is_charging = is_charging;
+		unit->is_discharging = !is_charging;
+		gpm_debug ("** EMIT: charging-changed: %i", is_charging);
+		g_signal_emit (cell, signals [CHARGING_CHANGED], 0, is_charging);
+	}
+
+	if (percentage != unit->percentage) {
+		unit->percentage = percentage;
+		gpm_debug ("** EMIT: percent-changed: %i", percentage);
+		g_signal_emit (cell, signals [PERCENT_CHANGED], 0, percentage);
+	}
+}
 
 /**
  * gpm_cell_class_init:
@@ -631,7 +713,13 @@ gpm_cell_init (GpmCell *cell)
 	cell->priv->technology = NULL;
 	cell->priv->serial = NULL;
 	cell->priv->model = NULL;
+
 	gpm_cell_unit_init (&cell->priv->unit);
+
+	cell->priv->phone = gpm_phone_new ();
+	cell->priv->sig_device_refresh =
+		g_signal_connect (cell->priv->phone, "device-refresh",
+	 			  G_CALLBACK (phone_device_refresh_cb), cell);
 }
 
 /**
@@ -648,11 +736,15 @@ gpm_cell_finalize (GObject *object)
 	cell = GPM_CELL (object);
 	cell->priv = GPM_CELL_GET_PRIVATE (cell);
 
+	/* we need to do this in case the device goes away and comes back */
+	g_signal_handler_disconnect (cell->priv->phone, cell->priv->sig_device_refresh);
+
 	g_free (cell->priv->product);
 	g_free (cell->priv->vendor);
 	g_free (cell->priv->technology);
 	g_free (cell->priv->serial);
 	g_free (cell->priv->model);
+	g_object_unref (cell->priv->phone);
 	g_object_unref (cell->priv->hal_device);
 }
 
@@ -668,3 +760,141 @@ gpm_cell_new (void)
 	return GPM_CELL (cell);
 }
 
+/***************************************************************************
+ ***                          MAKE CHECK TESTS                           ***
+ ***************************************************************************/
+#ifdef GPM_BUILD_TESTS
+#include "gpm-self-test.h"
+#include <libhal-gmanager.h>
+
+guint recall_count = 0;
+
+static void
+gpm_cell_perhaps_recall_cb (GpmCell *cell, gchar *oem_vendor, gchar *website, gpointer data)
+{
+	recall_count++;
+}
+
+static gchar *
+gpm_cell_get_battery (void)
+{
+	gchar **value;
+	gchar *udi = NULL;
+	gboolean ret;
+	HalGManager *manager;
+
+	manager = hal_gmanager_new ();
+	ret = hal_gmanager_find_capability (manager, "battery", &value, NULL);
+	if (ret == TRUE && value != NULL && value[0] != NULL) {
+		udi = g_strdup (value[0]);
+	}
+	hal_gmanager_free_capability (value);
+	g_object_unref (manager);
+
+	return udi;
+}
+
+
+void
+gpm_st_cell (GpmSelfTest *test)
+{
+	GpmCell *cell;
+	GpmCellUnit *unit;
+	gchar *desc;
+	gboolean ret;
+	gchar *udi;
+
+	if (gpm_st_start (test, "GpmCell", CLASS_AUTO) == FALSE) {
+		return;
+	}
+
+	/* get battery */
+	udi = gpm_cell_get_battery ();
+	if (udi == NULL) {
+		gpm_st_failed (test, "did not find battery device");
+	}
+
+	/************************************************************/
+	gpm_st_title (test, "make sure we get a non null cell");
+	cell = gpm_cell_new ();
+	g_signal_connect (cell, "perhaps-recall",
+			  G_CALLBACK (gpm_cell_perhaps_recall_cb), NULL);
+	if (cell != NULL) {
+		gpm_st_success (test, "got GpmCell");
+	} else {
+		gpm_st_failed (test, "could not get GpmCell");
+	}
+
+	/************************************************************/
+	gpm_st_title (test, "make sure we get a non null unit");
+	unit = gpm_cell_get_unit (cell);
+	if (unit != NULL) {
+		gpm_st_success (test, "got GpmCellUnit");
+	} else {
+		gpm_st_failed (test, "could not get GpmCellUnit");
+	}
+
+	/************************************************************/
+	gpm_st_title (test, "make sure we get a null description for nonassigned cell");
+	desc = gpm_cell_get_description (cell);
+	if (desc != NULL) {
+		gpm_st_success (test, "got description %s", desc);
+		g_free (desc);
+	} else {
+		gpm_st_failed (test, "could not get description");
+	}
+
+	/************************************************************/
+	gpm_st_title (test, "can we assign device");
+	ret = gpm_cell_set_hal_udi (cell, udi);
+	if (ret == TRUE) {
+		gpm_st_success (test, "set type okay");
+	} else {
+		gpm_st_failed (test, "could not set type");
+	}
+
+	/************************************************************/
+	gpm_st_title (test, "make sure we got a single recall notice");
+	if (recall_count == 1) {
+		gpm_st_success (test, "got recall");
+	} else {
+		gpm_st_failed (test, "did not get recall (install fdi?)");
+	}
+
+	/************************************************************/
+	gpm_st_title (test, "make sure we get a full description for set cell");
+	desc = gpm_cell_get_description (cell);
+	if (desc != NULL) {
+		gpm_st_success (test, "got description %s", desc);
+		g_free (desc);
+	} else {
+		gpm_st_failed (test, "could not get description");
+	}
+
+	/************************************************************/
+	gpm_st_title (test, "make sure we get a valid unit");
+	unit = gpm_cell_get_unit (cell);
+	if (unit->voltage > 1000 && unit->voltage < 20000) {
+		gpm_st_success (test, "got correct voltage");
+	} else {
+		gpm_st_failed (test, "could not get correct voltage %i", unit->voltage);
+	}
+
+	/************************************************************/
+	gpm_st_title (test, "make sure we get a id");
+	desc = gpm_cell_get_id (cell);
+	if (desc != NULL) {
+		gpm_st_success (test, "got valid id %s", desc);
+	} else {
+		gpm_st_failed (test, "could not get valid id");
+	}
+
+	g_free (udi);
+	g_free (desc);
+	g_object_unref (cell);
+
+	gpm_st_end (test);
+}
+
+#endif
+
