@@ -216,14 +216,17 @@ gpm_statistics_add_events_typical (GPtrArray *array)
 	gpm_statistics_add_event_type (array, GPM_EVENT_SUSPEND,
 				       GPM_COLOUR_RED,
 				       GPM_GRAPH_WIDGET_SHAPE_DIAMOND,
+				/* Translators: translate ONLY the string part after the |*/
 				       Q_("label shown on graph|Suspend"));
 	gpm_statistics_add_event_type (array, GPM_EVENT_RESUME,
 				       GPM_COLOUR_DARK_RED,
 				       GPM_GRAPH_WIDGET_SHAPE_DIAMOND,
+				/* Translators: translate ONLY the string part after the |*/
 				       Q_("label shown on graph|Resume"));
 	gpm_statistics_add_event_type (array, GPM_EVENT_HIBERNATE,
 				       GPM_COLOUR_MAGENTA,
 				       GPM_GRAPH_WIDGET_SHAPE_DIAMOND,
+				/* Translators: translate ONLY the string part after the |*/
 				       Q_("label shown on graph|Hibernate"));
 	gpm_statistics_add_event_type (array, GPM_EVENT_LID_CLOSED,
 				       GPM_COLOUR_GREEN,
@@ -289,7 +292,7 @@ gpm_statistics_get_parameters (GpmInfo   *info,
 		*axis_type_y = g_strdup ("power");
 		*axis_desc_x = g_strdup (_("Time since startup"));
 		*axis_desc_y = g_strdup (_("Power"));
-		gpm_statistics_add_data_type (*key_data, GPM_COLOUR_RED, _("Power"));
+		gpm_statistics_add_data_type (*key_data, GPM_COLOUR_DARK_RED, _("Power"));
 		gpm_statistics_add_events_typical (*key_event);
 		return TRUE;
 	}
@@ -298,7 +301,7 @@ gpm_statistics_get_parameters (GpmInfo   *info,
 		*axis_type_y = g_strdup ("time");
 		*axis_desc_x = g_strdup (_("Time since startup"));
 		*axis_desc_y = g_strdup (_("Estimated time"));
-		gpm_statistics_add_data_type (*key_data, GPM_COLOUR_RED, _("Time"));
+		gpm_statistics_add_data_type (*key_data, GPM_COLOUR_DARK_RED, _("Time"));
 		gpm_statistics_add_events_typical (*key_event);
 		return TRUE;
 	}
@@ -307,7 +310,7 @@ gpm_statistics_get_parameters (GpmInfo   *info,
 		*axis_type_y = g_strdup ("percentage");
 		*axis_desc_x = g_strdup (_("Time since startup"));
 		*axis_desc_y = g_strdup (_("Battery percentage"));
-		gpm_statistics_add_data_type (*key_data, GPM_COLOUR_RED, _("Percentage"));
+		gpm_statistics_add_data_type (*key_data, GPM_COLOUR_DARK_RED, _("Percentage"));
 		gpm_statistics_add_events_typical (*key_event);
 		return TRUE;
 	}
@@ -330,11 +333,11 @@ gpm_statistics_get_parameters (GpmInfo   *info,
 		gpm_statistics_add_event_type (*key_event, GPM_EVENT_HIBERNATE,
 					       GPM_COLOUR_CYAN,
 					       GPM_GRAPH_WIDGET_SHAPE_SQUARE,
-				 	      _("Charge Void"));
+				 	      _("Start point"));
 		gpm_statistics_add_event_type (*key_event, GPM_EVENT_SUSPEND,
 					       GPM_COLOUR_YELLOW,
 					       GPM_GRAPH_WIDGET_SHAPE_TRIANGLE,
-				 	      _("Discharge Void"));
+				 	      _("Stop point"));
 		return TRUE;
 	}
 	if (strcmp (type, "profile-charge-time") == 0) {
@@ -342,16 +345,17 @@ gpm_statistics_get_parameters (GpmInfo   *info,
 		*axis_type_y = g_strdup ("time");
 		*axis_desc_x = g_strdup (_("Battery percentage"));
 		*axis_desc_y = g_strdup (_("Average time elapsed"));
-		gpm_statistics_add_data_type (*key_data, GPM_COLOUR_BLUE, _("Valid data"));
-		gpm_statistics_add_data_type (*key_data, GPM_COLOUR_DARK_BLUE, _("No data"));
+		gpm_statistics_add_data_type (*key_data, GPM_COLOUR_RED, _("Valid data"));
+		gpm_statistics_add_data_type (*key_data, GPM_COLOUR_BLUE, _("No data"));
+		gpm_statistics_add_data_type (*key_data, GPM_COLOUR_DARK_GREY, _("Extrapolated data"));
 		gpm_statistics_add_event_type (*key_event, GPM_EVENT_HIBERNATE,
 					       GPM_COLOUR_CYAN,
 					       GPM_GRAPH_WIDGET_SHAPE_SQUARE,
-				 	      _("Charge Void"));
+				 	      _("Start point"));
 		gpm_statistics_add_event_type (*key_event, GPM_EVENT_SUSPEND,
 					       GPM_COLOUR_YELLOW,
 					       GPM_GRAPH_WIDGET_SHAPE_TRIANGLE,
-				 	      _("Discharge Void"));
+				 	      _("Stop point"));
 		return TRUE;
 	}
 	if (strcmp (type, "profile-discharge-accuracy") == 0) {
@@ -364,11 +368,11 @@ gpm_statistics_get_parameters (GpmInfo   *info,
 		gpm_statistics_add_event_type (*key_event, GPM_EVENT_HIBERNATE,
 					       GPM_COLOUR_CYAN,
 					       GPM_GRAPH_WIDGET_SHAPE_SQUARE,
-				 	      _("Charge Void"));
+				 	      _("Start point"));
 		gpm_statistics_add_event_type (*key_event, GPM_EVENT_SUSPEND,
 					       GPM_COLOUR_YELLOW,
 					       GPM_GRAPH_WIDGET_SHAPE_TRIANGLE,
-				 	      _("Discharge Void"));
+				 	      _("Stop point"));
 		return TRUE;
 	}
 	if (strcmp (type, "profile-discharge-time") == 0) {
@@ -377,15 +381,16 @@ gpm_statistics_get_parameters (GpmInfo   *info,
 		*axis_desc_x = g_strdup (_("Battery percentage"));
 		*axis_desc_y = g_strdup (_("Average time elapsed"));
 		gpm_statistics_add_data_type (*key_data, GPM_COLOUR_RED, _("Valid data"));
-		gpm_statistics_add_data_type (*key_data, GPM_COLOUR_DARK_RED, _("No data"));
+		gpm_statistics_add_data_type (*key_data, GPM_COLOUR_BLUE, _("No data"));
+		gpm_statistics_add_data_type (*key_data, GPM_COLOUR_DARK_GREY, _("Extrapolated data"));
 		gpm_statistics_add_event_type (*key_event, GPM_EVENT_HIBERNATE,
 					       GPM_COLOUR_CYAN,
 					       GPM_GRAPH_WIDGET_SHAPE_SQUARE,
-				 	      _("Charge Void"));
+				 	      _("Start point"));
 		gpm_statistics_add_event_type (*key_event, GPM_EVENT_SUSPEND,
 					       GPM_COLOUR_YELLOW,
 					       GPM_GRAPH_WIDGET_SHAPE_TRIANGLE,
-				 	      _("Discharge Void"));
+				 	      _("Stop point"));
 		return TRUE;
 	}
 
