@@ -49,7 +49,7 @@ static void gpm_exit (GpmManager *manager);
  * @connection: What we want to register to
  * @object: The GObject we want to register
  *
- * Register org.gnome.PowerManager on the session bus.
+ * Register org.freedesktop.PowerManagement on the session bus.
  * This function MUST be called before DBUS service will work.
  *
  * Return value: success
@@ -218,6 +218,7 @@ main (int argc, char *argv[])
 
 	gpm_debug ("GNOME %s %s", GPM_NAME, VERSION);
 
+if (0) {
 	/* check dbus connections, exit if not valid */
 	system_connection = dbus_g_bus_get (DBUS_BUS_SYSTEM, &error);
 	if (error) {
@@ -228,6 +229,7 @@ main (int argc, char *argv[])
 			   "It is <b>strongly recommended</b> you reboot "
 			   "your computer after starting this service.");
 	}
+}
 
 	session_connection = dbus_g_bus_get (DBUS_BUS_SESSION, &error);
 	if (error) {
@@ -250,7 +252,7 @@ main (int argc, char *argv[])
 	manager = gpm_manager_new ();
 
 	if (!gpm_object_register (session_connection, G_OBJECT (manager))) {
-		gpm_warning ("%s is already running in this session.", GPM_NAME);
+		gpm_error ("%s is already running in this session.", GPM_NAME);
 		return 0;
 	}
 
@@ -275,7 +277,9 @@ main (int argc, char *argv[])
 	g_object_unref (manager);
 unref_program:
 	g_object_unref (program);
+/*
 	g_option_context_free (context);
+*/
 
 	return 0;
 }
