@@ -383,7 +383,7 @@ gpm_notify_low_capacity (GpmNotify *notify,
 	gchar *msg;
 	const gchar *title;
 
-	title = _("Battery may be invalid");
+	title = _("Battery may be broken");
 	msg = g_strdup_printf (_("Your battery has a very low capacity (%i%%), "
 				 "which means that it may be old or broken."),
 			       capacity);
@@ -563,6 +563,12 @@ gpm_notify_sleep_failed (GpmNotify *notify, gboolean hibernate)
 	                                 notify, NULL);
 
 	notify->priv->internet_url = g_strdup (QUIRK_WEBSITE);
+	/* Translator: Quirks refer to strange/weird/undocumented behaviour of
+	 * hardware.  Because the manufacturers do not provide the necessary
+	 * information for non-FOSS software support, it is up to the users to
+	 * supply the info by following the procedures outlined in the "Quirks
+	 * website" at http://people.freedesktop.org/~hughsient/quirk/.
+	 */
 	notify_notification_add_action  (notify->priv->libnotify,
 	                                 "visit-website",
 	                                 _("Visit quirk website"),
